vfbLib.parsers.bitmap.BaseBitmapParser
======================================

.. currentmodule:: vfbLib.parsers.bitmap

.. autoclass:: BaseBitmapParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BaseBitmapParser.__init__
      ~BaseBitmapParser.parse
      ~BaseBitmapParser.parse_bitmap_data
      ~BaseBitmapParser.parse_hex
      ~BaseBitmapParser.read_double
      ~BaseBitmapParser.read_doubles
      ~BaseBitmapParser.read_float
      ~BaseBitmapParser.read_floats
      ~BaseBitmapParser.read_int16
      ~BaseBitmapParser.read_int32
      ~BaseBitmapParser.read_int8
      ~BaseBitmapParser.read_str
      ~BaseBitmapParser.read_str_all
      ~BaseBitmapParser.read_uint16
      ~BaseBitmapParser.read_uint32
      ~BaseBitmapParser.read_uint8
      ~BaseBitmapParser.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BaseBitmapParser.encoding
      ~BaseBitmapParser.master_count
      ~BaseBitmapParser.stream
      ~BaseBitmapParser.ttStemsH_count
      ~BaseBitmapParser.ttStemsV_count
   
   